@@ -19,18 +19,6 @@ extern "C"
 
 #include <hubbub/types.h>
 
-/**
- * Type of allocation function for hubbub 
- *
- * The semantics of this function are the same as for realloc().
- *
- * \param ptr   Pointer to object to reallocate, or NULL for a new allocation
- * \param size  Required length in bytes, or zero to free ::ptr
- * \param pw    Pointer to client data
- * \return Pointer to allocated object, or NULL on failure
- */
-typedef void *(*hubbub_allocator_fn)(void *ptr, size_t size, void *pw);
-
 /**
  * Type of token handling function
  *
@@ -45,7 +33,7 @@ typedef hubbub_error (*hubbub_token_handler)(
  * Type of parse error handling function
  *
  * \param line     Source line on which error occurred
- * \param col      Column in ::line of start of erroneous input
+ * \param col      Column in \p line of start of erroneous input
  * \param message  Error message
  * \param pw       Pointer to client data
  */
